==> kubernetes-model-extensions-5.9.0-sources.jar: io/fabric8/kubernetes/api/model/extensions/DeploymentStrategyBuilder.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class DeploymentStrategyBuilder extends io.fabric8.kubernetes.api.model.extensions.DeploymentStrategyFluentImpl<io.fabric8.kubernetes.api.model.extensions.DeploymentStrategyBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.extensions.DeploymentStrategy,io.fabric8.kubernetes.api.model.extensions.DeploymentStrategyBuilder>{
  public DeploymentStrategyBuilder() {
    this(false);
  }
  public DeploymentStrategyBuilder(java.lang.Boolean validationEnabled) {
    this(new DeploymentStrategy(), validationEnabled);
  }
  public DeploymentStrategyBuilder(io.fabric8.kubernetes.api.model.extensions.DeploymentStrategyFluent<?> fluent) {
    this(fluent, false);
  }
  public DeploymentStrategyBuilder(io.fabric8.kubernetes.api.model.extensions.DeploymentStrategyFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new DeploymentStrategy(), validationEnabled);
  }
  public DeploymentStrategyBuilder(io.fabric8.kubernetes.api.model.extensions.DeploymentStrategyFluent<?> fluent,io.fabric8.kubernetes.api.model.extensions.DeploymentStrategy instance) {
    this(fluent, instance, false);
  }
  public DeploymentStrategyBuilder(io.fabric8.kubernetes.api.model.extensions.DeploymentStrategyFluent<?> fluent,io.fabric8.kubernetes.api.model.extensions.DeploymentStrategy instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withRollingUpdate(instance.getRollingUpdate()); 
    fluent.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  public DeploymentStrategyBuilder(io.fabric8.kubernetes.api.model.extensions.DeploymentStrategy instance) {
    this(instance,false);
  }
  public DeploymentStrategyBuilder(io.fabric8.kubernetes.api.model.extensions.DeploymentStrategy instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withRollingUpdate(instance.getRollingUpdate()); 
    this.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.extensions.DeploymentStrategyFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.extensions.DeploymentStrategy build() {
    DeploymentStrategy buildable = new DeploymentStrategy(fluent.getRollingUpdate(),fluent.getType());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DeploymentStrategyBuilder that = (DeploymentStrategyBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-extensions-5.11.1-sources.jar: io/fabric8/kubernetes/api/model/extensions/DeploymentStrategyBuilder.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class DeploymentStrategyBuilder extends io.fabric8.kubernetes.api.model.extensions.DeploymentStrategyFluentImpl<io.fabric8.kubernetes.api.model.extensions.DeploymentStrategyBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.extensions.DeploymentStrategy,io.fabric8.kubernetes.api.model.extensions.DeploymentStrategyBuilder>{
  public DeploymentStrategyBuilder() {
    this(false);
  }
  public DeploymentStrategyBuilder(java.lang.Boolean validationEnabled) {
    this(new DeploymentStrategy(), validationEnabled);
  }
  public DeploymentStrategyBuilder(io.fabric8.kubernetes.api.model.extensions.DeploymentStrategyFluent<?> fluent) {
    this(fluent, false);
  }
  public DeploymentStrategyBuilder(io.fabric8.kubernetes.api.model.extensions.DeploymentStrategyFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new DeploymentStrategy(), validationEnabled);
  }
  public DeploymentStrategyBuilder(io.fabric8.kubernetes.api.model.extensions.DeploymentStrategyFluent<?> fluent,io.fabric8.kubernetes.api.model.extensions.DeploymentStrategy instance) {
    this(fluent, instance, false);
  }
  public DeploymentStrategyBuilder(io.fabric8.kubernetes.api.model.extensions.DeploymentStrategyFluent<?> fluent,io.fabric8.kubernetes.api.model.extensions.DeploymentStrategy instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withRollingUpdate(instance.getRollingUpdate()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public DeploymentStrategyBuilder(io.fabric8.kubernetes.api.model.extensions.DeploymentStrategy instance) {
    this(instance,false);
  }
  public DeploymentStrategyBuilder(io.fabric8.kubernetes.api.model.extensions.DeploymentStrategy instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withRollingUpdate(instance.getRollingUpdate()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.extensions.DeploymentStrategyFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.extensions.DeploymentStrategy build() {
    DeploymentStrategy buildable = new DeploymentStrategy(fluent.getRollingUpdate(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DeploymentStrategyBuilder that = (DeploymentStrategyBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
